.. _simulation:

=========================================
Simulation utilities (`skhep.simulation`)
=========================================

.. automodule:: skhep.simulation
   :members:

.. automodule:: skhep.simulation.pdgid
   :members:
